@@ -15,7 +15,10 @@
 #
 
 
-from .single_model import RestEndpointBuilder, RestEntityBuilder
+from splunk_add_on_ucc_framework.uccrestbuilder.endpoint.single_model import (
+    RestEndpointBuilder,
+    RestEntityBuilder,
+)
 
 
 class DataInputEntityBuilder(RestEntityBuilder):
